const { format } = require('../src/format');

describe('format', () => {
  it('removes extra whitespace', () => {
    const codeSnippet = 'public   int Foo()'
    expect(format(codeSnippet)).toBe('public int Foo()')
  })

  it('trims leading & trailing whitespace', () => {
    const codeSnippet = ' public int Foo()\t '
    expect(format(codeSnippet)).toBe('public int Foo()')
  })

  it('replaces tab characters with whitespace', () => {
    const codeSnippet = 'public   int \t Foo(\t)'
    expect(format(codeSnippet)).toBe('public int Foo()')
  })

  it('arranges commas', () => {
    const codeSnippet = 'a , b\t,   c  ,'
    expect(format(codeSnippet)).toBe('a, b, c,')

  })

  describe('methods', () => {
    it('transforms inline braces to expression bodied member', () => {
      const codeSnippet = 'Foo() { return 2; }';
      expect(format(codeSnippet)).toBe('Foo() => 2;')
    })

    it('distinguishes between methods and object/collection initializers', () => {
      const codeSnippet = 'Foo(){ return 2; }';
      expect(format(codeSnippet)).toBe('Foo() => 2;')
    })

  })


  describe('collection/object initializer', () => {
    it('removes unnecessary parentheses', () => {
      const codeSnippet = 'new List<int>(){ 2, 3, 5}'
      expect(format(codeSnippet))
        .toBe('new List<int>{ 2, 3, 5}')
    })
    it('does not remove necessary parentheses', () => {
      const codeSnippet = 'new List<int>(3){ 2, 3, 5}'
      expect(format(codeSnippet))
        .toBe(codeSnippet)
    })
  })

} )